// import classes
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { FormGroup, FormControl, Validators, FormBuilder } from '@angular/forms';
import { CategoryService } from '../category.service';
import { Observable} from 'rxjs';
import { Category } from '../category';

// mark this class as angular component using @Component decorator
@Component({
    selector: 'app-create-category',
    templateUrl: './create-category.component.html',
    styleUrls: ['./create-category.component.css'],
    providers: [CategoryService]
})

// component for creating a category record
export class CreateCategoryComponent {

    // our angular form
    create_category_form: FormGroup;

    // @Output will tell the parent component (CategoriesComponent) that an event happend in this component
    @Output() show_read_categories_event = new EventEmitter();

    // list of categories
    categories: Category[];

    // initialize 'category service' and 'form builder'
    constructor(
        private categoryService: CategoryService,
        formBuilder: FormBuilder
    ){
        // based on our html form, build our angular form
        this.create_category_form = formBuilder.group({
            name: ["", Validators.required],
            description: ["", Validators.required]
        });
    }

    // user clicks 'create' button
    createCategory(){
        console.log('createCategory called.');
        // send data to server
        this.categoryService.createCategory(this.create_category_form.value)
            .subscribe(
                 category => {

                    // dispaly response in the console
                    console.log(category);

                    // go back to list of categories
                    this.readCategories();
                 },
                 error => console.log(error)
             );
    }

    // user clicks the 'read categories' button
    readCategories(){
        this.show_read_categories_event.emit({ title: "Read Categories" });
    }

}
