// import classes
import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { CategoryService } from '../category.service';
import { Observable} from 'rxjs';
import { Category } from '../category';

// mark this class as angular component using @Component decorator
@Component({
    selector: 'app-read-categories',
    templateUrl: './read-categories.component.html',
    styleUrls: ['./read-categories.component.css'],
    providers: [CategoryService]
})

// component for reading list of categories
export class ReadCategoriesComponent implements OnInit {

    /*
        * Needed to notify the 'consumer of this component', which is the 'CategoriesComponent',
          that an 'event' happened in this component.
    */
    @Output() show_create_category_event=new EventEmitter();
    @Output() show_read_one_category_event=new EventEmitter();
    @Output() show_update_category_event=new EventEmitter();
    @Output() show_delete_category_event=new EventEmitter();

    // store list of categories
    categories: Category[];

    // initialize CategoryService to retrieve list categories in the ngOnInit()
    constructor(private categoryService: CategoryService){}

    // when user clicks the 'create' button
    createCategory(){

        // tell the parent component (CategoriesComponent)
        this.show_create_category_event.emit({
            title: "Create Category"
        });
    }

    // when user clicks the 'read' button
    readOneCategory(id){
        console.log("readOneCategory comp:" + id);
        // tell the parent component (CategoriesComponent)
        this.show_read_one_category_event.emit({
            category_id: id,
            title: "Read One Category"
        });
    }

    // when user clicks the 'update' button
    updateCategory(id){

        // tell the parent component (CategoriesComponent)
        this.show_update_category_event.emit({
            category_id: id,
            title: "Update Category"
        });
    }

    // when user clicks the 'delete' button
    deleteCategory(id){
        // tell the parent component (CategoriesComponent)
        this.show_delete_category_event.emit({
            category_id: id,
            title: "Delete Category"
        });
    }

    // Read categories from API.
    ngOnInit(){
        this.categoryService.readCategories()
            .subscribe(categories =>
                this.categories=categories
            );
    }
}
