// import classes
import { Component, Output, EventEmitter } from '@angular/core';

// mark this class as angular component using @Component decorator
@Component({
    selector: 'app-products',
    templateUrl: './products.component.html',
    styleUrls: ['./products.component.css']
})

// component for products
export class ProductsComponent {

    // tell AppComponent it needs to change the title
    @Output() change_title_event = new EventEmitter();

    // properties for child components
    product_id;

    // properties used to identify what views to show
    show_read_products_html=true;
    show_create_product_html=false;
    show_read_one_product_html=false;
    show_update_product_html=false;
    show_delete_product_html=false;

    // show details of a product
    showReadOneProduct($event){

        // set title and product ID
        this.changeTitle($event.title);
        this.product_id=$event.product_id;

        // hide all html then show only one html
        this.hideAll_Html();
        this.show_read_one_product_html=true;
    }

    // show the 'create product form'
    showCreateProduct($event){

        // set title
        this.changeTitle($event.title);

        // hide all html then show only one html
        this.hideAll_Html();
        this.show_create_product_html=true;
    }

    // show products list
    showReadProducts($event){
        // set title
        this.changeTitle($event.title);

        // hide all html then show only one html
        this.hideAll_Html();
        this.show_read_products_html=true;
    }

    // show the 'update product form'
    showUpdateProduct($event){

        // set title and product ID
        this.changeTitle($event.title);
        this.product_id=$event.product_id;

        // hide all html then show only one html
        this.hideAll_Html();
        this.show_update_product_html=true;
    }

    // show 'are you sure?' prompt to confirm deletion of a record
    showDeleteProduct($event){

        // set title and product ID
        this.changeTitle($event.title);
        this.product_id=$event.product_id;

        // hide all html then show only one html
        this.hideAll_Html();
        this.show_delete_product_html=true;
    }

    // hide all html views
    hideAll_Html(){
        this.show_read_products_html=false;
        this.show_read_one_product_html=false;
        this.show_create_product_html=false;
        this.show_update_product_html=false;
        this.show_delete_product_html=false;
    }

    // change title in app component
    changeTitle(new_title){
        this.change_title_event.emit({ title: new_title });
    }
}
